==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.bg = function () {
        return new MarketFacilitationIndexIndicator();
    };
    MarketFacilitationIndexIndicator.prototype.get_x6 = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_zl = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zl", {
        get: function () {
            return this.get_zl();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_zc = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.bc = function () {
        return new MarketFacilitationIndexIndicator();
    };
    MarketFacilitationIndexIndicator.prototype.get_x7 = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_zm = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zm", {
        get: function () {
            return this.get_zm();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_zd = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };
